#!/usr/bin/env python
import random

class InvalidAmountError(Exception):
    """ Exception for an invalid amount of words """
    pass

class WORD:
    """ Generates random words securely from a list. """
    def __init__(self, word_list):
        # Potentially use strip() to get rid of 0x0a
        with open(word_list, 'r') as word_file:
            self.words = [line.rstrip() for line in word_file] # Strip 0x0a
        if len(self.words) <= 0:
            raise IndexError("No words can be loaded from file '{}'".format(word_list))

    def getWords(self, amount):
        """ Returns a list of randomly selected words of length `amount`."""
        if amount <= 0 or amount > len(self.words):
            raise InvalidAmountError("No words available with amount {}".format(amount))
        else:
            words = []
            random.seed()
            for x in range(0, amount):
                word = random.choice(self.words)
                # If the word is in words, try again
                # TODO Keep this from infinitely looping if the wordlist is bad
                while word in words:
                    word = random.choice(self.words)
                words.append(word)
        return words
